/*
 * Copyright (C) 2000-2003 Damien Douxchamps  <ddouxchamps@users.sf.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __BUILDMENUS_H__
#define __BUILDMENUS_H__

void
BuildTriggerModeMenu(void);

void
BuildTriggerSourceMenu(void);

void
BuildMemoryChannelMenu(void);

void
BuildCameraMenu(void);

void
BuildFormat7ColorMenu(void);

void
BuildFormat7ModeMenu(void);

void
BuildIsoSpeedMenu(void);

void
BuildFpsMenu(void);

void
BuildFormatMenu(void);

void
BuildBayerMenu(void);

void
BuildBayerPatternMenu(void);

void
BuildStereoMenu(void);

void
BuildOverlayTypeMenu(void);

void
BuildOverlayPatternMenu(void);

void
BuildSaveFormatMenu(void);

void
BuildSaveAppendMenu(void);

void
BuildRegisterAccessOffsetMenu(void);

#endif // __BUILDMENUS_H__
